@@ -38,7 +38,7 @@ if TYPE_CHECKING:
     from sqlalchemy.sql.schema import Constraint
     from sqlalchemy.sql.type_api import TypeEngine
 
-    from .base import _ServerDefault
+    from .base import _ServerDefaultType
 
 
 class MySQLImpl(DefaultImpl):
@@ -83,13 +83,15 @@ class MySQLImpl(DefaultImpl):
         *,
         nullable: Optional[bool] = None,
         server_default: Optional[
-            Union[_ServerDefault, Literal[False]]
+            Union[_ServerDefaultType, Literal[False]]
         ] = False,
         name: Optional[str] = None,
         type_: Optional[TypeEngine] = None,
         schema: Optional[str] = None,
         existing_type: Optional[TypeEngine] = None,
-        existing_server_default: Optional[_ServerDefault] = None,
+        existing_server_default: Optional[
+            Union[_ServerDefaultType, Literal[False]]
+        ] = None,
         existing_nullable: Optional[bool] = None,
         autoincrement: Optional[bool] = None,
         existing_autoincrement: Optional[bool] = None,
@@ -207,7 +209,7 @@ class MySQLImpl(DefaultImpl):
     def _is_mysql_allowed_functional_default(
         self,
         type_: Optional[TypeEngine],
-        server_default: Optional[Union[_ServerDefault, Literal[False]]],
+        server_default: Optional[Union[_ServerDefaultType, Literal[False]]],
     ) -> bool:
         return (
             type_ is not None
@@ -358,7 +360,7 @@ class MySQLAlterDefault(AlterColumn):
         self,
         name: str,
         column_name: str,
-        default: Optional[_ServerDefault],
+        default: Optional[_ServerDefaultType],
         schema: Optional[str] = None,
     ) -> None:
         super(AlterColumn, self).__init__(name, schema=schema)
@@ -375,7 +377,7 @@ class MySQLChangeColumn(AlterColumn):
         newname: Optional[str] = None,
         type_: Optional[TypeEngine] = None,
         nullable: Optional[bool] = None,
-        default: Optional[Union[_ServerDefault, Literal[False]]] = False,
+        default: Optional[Union[_ServerDefaultType, Literal[False]]] = False,
         autoincrement: Optional[bool] = None,
         comment: Optional[Union[str, Literal[False]]] = False,
     ) -> None:
@@ -464,7 +466,7 @@ def _mysql_change_column(
 def _mysql_colspec(
     compiler: MySQLDDLCompiler,
     nullable: Optional[bool],
-    server_default: Optional[Union[_ServerDefault, Literal[False]]],
+    server_default: Optional[Union[_ServerDefaultType, Literal[False]]],
     type_: TypeEngine,
     autoincrement: Optional[bool],
     comment: Optional[Union[str, Literal[False]]],
